from setuptools import setup, find_packages 
 
setup( 
   name="Kissimoney2023", 
   version="0.0.1", 
   author="Kissimoney2023", 
   author_email="sahjohnny@gmail.com", 
   description="Faceswap", 
   long_description=open("README.md").read(), 
   long_description_content_type="text/markdown", 
   url="https://github.com/pypa/sampleproject", 
   packages=find_packages(), 
   classifiers=[ 
       "Programming Language :: Python :: 3", 
       "License :: OSI Approved :: MIT License", 
       "Operating System :: OS Independent", 
   ], 
   python_requires='>=3.8',

) 
